#
# spec file for package python3-sip
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rversion %{version}
%define python_sip_api 10.1

Name:           python3-sip
Version:        4.15.3
Release:        0
Summary:        SIP tool to use python sip bindings
License:        GPL-2.0 or GPL-3.0 or SUSE-SIP
Group:          Development/Libraries/Python
Url:            http://www.riverbankcomputing.com/software/sip/intro
Source0:        http://downloads.sourceforge.net/project/pyqt/sip/sip-%{rversion}/sip-%{rversion}.tar.gz
# PATCH-FIX-OPENSUSE disable-rpaths.diff -- Disable rpaths
Patch0:         disable-rpaths.diff
# PATCH-FIX-OPENSUSE build-compare.diff cmorve69@yahoo.es -- Fix build-compare
Patch1:         build-compare.diff
BuildRequires:  c++_compiler
BuildRequires:  python3-devel
Provides:       python3-sip(api) = %python_sip_api
Requires(pre):  python3
Requires(pre):  python3-base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} == 1220
%define py3_incdir %{_includedir}/python3.2mu
%endif

%description
SIP is a tool that makes it very easy to create Python bindings for C
and C++ libraries. It was originally developed to create PyQt, the
Python bindings for the Qt toolkit, but can be used to create bindings
for any C or C++ library.

%package devel
Summary:        SIP tool to create python bindings
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       c++_compiler
Requires:       python3-devel
Requires(post):       update-alternatives
Provides:       python3-sip-bin = %{version}
Obsoletes:      python3-sip-bin < %{version}

%description devel
SIP is a tool that makes it very easy to create Python bindings for C
and C++ libraries. It was originally developed to create PyQt, the
Python bindings for the Qt toolkit, but can be used to create bindings
for any C or C++ library.

This package contains all the developer tools you need to create your
own sip bindings.

%prep
%setup -q -n sip-%{rversion}
%patch0
%patch1

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
# Link against libpython (fixes bnc#756282 and bnc#721280)
python3 configure.py --debug CFLAGS+="%{optflags}" CXXFLAGS+="%{optflags}" LIBS+="-lpython%{py3_ver}%{py3_abiflags}"
make %{?_smp_mflags}

sip_major=$(grep "define SIP_API_MAJOR_NR" siplib/sip.h.in | awk '{print $3}')
sip_minor=$(grep "define SIP_API_MINOR_NR" siplib/sip.h.in | awk '{print $3}')

if test "%python_sip_api" != "$sip_major.$sip_minor"; then
    echo "API version was changed to $sip_major.$sip_minor"
    exit 1
fi

echo "%%requires_python3_sip_api Requires: python3-sip(api) = $sip_major.$sip_minor" > macros.%name

%install
%{make_install}
mkdir -p %{buildroot}%{_datadir}/sip

# For alternatives
mv %{buildroot}%{_bindir}/sip %{buildroot}%{_bindir}/sip-%{py3_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/sip
ln -s -f %{_sysconfdir}/alternatives/sip %{buildroot}/%{_bindir}/sip

# Point to the correct location for the documentation files
sed -i 's/"doc" directory/"doc" directory of package %{name}-devel/' README

install -m 644 -D macros.%name %{buildroot}/%{_sysconfdir}/rpm/macros.%name

%post devel
# Lower priority than the python 2.x version for now
update-alternatives --install %{_bindir}/sip sip %{_bindir}/sip-%{py3_ver} 40

%preun devel

if ["$1" = 0] ; then
    update-alternatives --remove sip %{_bindir}/sip-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc README
%{python3_sitearch}/sip.so

%files devel
%defattr(-,root,root,-)
%doc NEWS LICENSE* doc/
%config %{_sysconfdir}/rpm/macros.%name
%{_bindir}/sip-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/sip
%{_bindir}/sip
%{py3_incdir}/sip.h
%{python3_sitearch}/sipconfig.py
%{python3_sitearch}/sipdistutils.py
%{_datadir}/sip/

%changelog
